==> metabolator-v0.1.0.zip: README.md <==
<!--
SPDX-FileCopyrightText: 2024 Helmholtz-Zentrum Dresden - Rossendorf (HZDR)

SPDX-License-Identifier: CC-BY-SA-4.0
-->

# METABOLATOR: Analysis of Microcalorimetric Metabolic Data Using Monod's Equation

Curve fitting automation for metabolic load of bacteria in solutions.
The service is deployed at HZDR and available at <https://calorimetric.hzdr.de>.

## Installation

This requires [Poetry](https://python-poetry.org/).

Install the package and its dependencies:

```bash
poetry install
```

To install the development dependencies as well, run:

```bash
poetry install --with dev
```

## Usage

Enter the virtual environment by running:

```bash
poetry shell
```

Within Poetry shell, run this project as a Jupyter Notebook:

```bash
jupyter notebook metabolator/METABOLATOR.ipynb
```

Run with Voilà:

```bash
voila metabolator/METABOLATOR.ipynb
```

## Development

Format the code (within Poetry shell):

```bash
ruff format .
```

Run the linter and apply potential fixes (within Poetry shell):

```bash
ruff check --fix .
```

## Deployment

The `conf` directory contains an [example service file for systemd](conf/metabolator.service.example)
as well as an [example nginx configuration](conf/metabolator.example.com).
We suggest running the application service as a dedicated user (not root).
This can be achieved by enabling lingering for the user with `loginctl`.
For more information see the [Voilà documentation](https://voila.readthedocs.io/en/stable/deploy.html#running-voila-on-a-private-server).

## Providing Example Datasets

Example dataset files (common spreadsheet formats) can be placed inside the
`metabolator/static/datasets` directory.
Please make sure to place a license file next to the dataset.
This can be done with `reuse annotate`

==> metabolator-v0.1.1.zip: README.md <==
<!--
SPDX-FileCopyrightText: 2024 Helmholtz-Zentrum Dresden - Rossendorf (HZDR)

SPDX-License-Identifier: CC-BY-SA-4.0
-->

# METABOLATOR: Analysis of Microcalorimetric Metabolic Data Using Monod's Equation

Curve fitting automation for metabolic load of bacteria in solutions.
The service is deployed at HZDR and available at <https://metabolator.hzdr.de>.

## Installation

This requires [Poetry](https://python-poetry.org/).

Install the package and its dependencies:

```bash
poetry install
```

To install the development dependencies as well, run:

```bash
poetry install --with dev
```

## Usage

Enter the virtual environment by running:

```bash
poetry shell
```

Within Poetry shell, run this project as a Jupyter Notebook:

```bash
jupyter notebook metabolator/METABOLATOR.ipynb
```

Run with Voilà:

```bash
voila metabolator/METABOLATOR.ipynb
```

## Development

Format the code (within Poetry shell):

```bash
ruff format .
```

Run the linter and apply potential fixes (within Poetry shell):

```bash
ruff check --fix .
```

## Deployment

The `conf` directory contains an [example service file for systemd](conf/metabolator.service.example)
as well as an [example nginx configuration](conf/metabolator.example.com).
We suggest running the application service as a dedicated user (not root).
This can be achieved by enabling lingering for the user with `loginctl`.
For more information see the [Voilà documentation](https://voila.readthedocs.io/en/stable/deploy.html#running-voila-on-a-private-server).

## Providing Example Datasets

Example dataset files (common spreadsheet formats) can be placed inside the
`metabolator/static/datasets` directory.
Please make sure to place a license file next to the dataset.
This can be done with `reuse annotate`
